/**
 * @file m13_ra6m3_ek_switch.c
 * @brief M13-RA6M3-EK switch BSP
 *
 * @section License
 *
 * SPDX-License-Identifier: Apache-2.0
 *
 * Copyright (C) 2020-2021 M13DESIGN SARL. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http:// www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @author M13DESIGN SARL (www.m13design.fr)
 * @version 1.0.0
 **/

#include "m13_ra6m3_ek_switch.h"
#include "m13_ra6m3_ek_pinout.h"

// Switch IOPORT structure
static ioport_instance_ctrl_t sw_pin_ctrl;

/**
 * @name       bsp_switch_io_init 
 * @brief      Initialize and configure the button/switch pins
 * @param[in]  None
 * @return     None
 **/
void bsp_switch_io_init (void)
{
    ioport_cfg_t sw_pin_cfg;

    sw_pin_cfg.number_of_pins = sizeof(m13_ra6m3_ek_switch_pin_data)/sizeof(ioport_pin_cfg_t);
    sw_pin_cfg.p_pin_cfg_data = &m13_ra6m3_ek_switch_pin_data[0];

    //Configure led pins
    R_IOPORT_Open(&sw_pin_ctrl, &sw_pin_cfg);
}

/**
 * @name       bsp_switch_status
 * @brief      Get the button/switch status/level
 * @param[in]  channel : The switch channel
 * @return     switch_state : The switch level status
 **/
bsp_switch_state_t bsp_switch_status (bsp_switch_channel_t channel)
{
    bsp_io_level_t  switch_state;

    R_IOPORT_PinRead(&sw_pin_ctrl, channel, &switch_state);

    return switch_state;
}

