//Dependencies
#include "main_thread.h"
#include "bsp_api.h"

#include "m13_ra6m3_ek_led.h"
#include "m13_ra6m3_ek_vcom.h"
#include "m13_ra6m3_ek_adc.h"
#include "m13_ra6m3_ek_acc.h"
#include "m13_ra6m3_ek_ethernet.h"
#include "m13_ra6m3_ek_touch.h"
#include "m13_ra6m3_ek_led.h"

// Global variables
SemaphoreHandle_t i2c_channel_0_semaphore;

// External task definitions
extern void ethernet_task(void *parameters);
extern void accelerometer_task(void *parameters);
extern void adc_task(void *parameters);
extern void lcd_task(void *parameters);
extern void touch_task(void *pvParameters);
extern void audio_task(void *pvParameters);

// Main Thread entry function
void main_thread_entry(void *pvParameters)
{
    FSP_PARAMETER_NOT_USED (pvParameters);

    portBASE_TYPE status;
    TaskHandle_t task;

    //Initialize UART for debug
    bsp_vcom_init();

    // Open SCI channel 4
    bsp_vcom_open(BSP_VCOM_CHANNEL_4);

    // Configure the led pins
    bsp_led_io_init();

    // Configure the ADC pins
    bsp_adc_io_init();

    // Create Mutex for I2C channel 0 access
    i2c_channel_0_semaphore = xSemaphoreCreateMutex();

    // Configure i2c0 pins
    bsp_i2c_init(BSP_I2C_CHANNEL_0);

    // Initialize & configure the accelerometer
    bsp_acc_init();

    // Init touch
    bsp_touch_init();

    // Initialize the Ethernet Pins
    bsp_ethernet_init();

    // Start-up message
    PRINTF_INFO("\r\n");
    PRINTF_INFO(" **************************************** \r\n");
    PRINTF_INFO(" ************ M13design Demo ************ \r\n");
    PRINTF_INFO(" **************************************** \r\n");
    PRINTF_INFO("Copyright: 2010-2021 M13design SARL\r\n");
    PRINTF_INFO("Compiled: %s %s\r\n", __DATE__, __TIME__);
    PRINTF_INFO("Target: RA6M3\r\n");
    PRINTF_INFO("\r\n");

    // Create Ethernet task
    status = xTaskCreate(ethernet_task, "Ethernet Task", 1000, NULL, 2, &task);

    if( status != pdPASS )
    {
        PRINTF_INFO("Could not create Ethernet task \r\n");
    }

    // Create Accelerometer task
    status = xTaskCreate(accelerometer_task, "Accelerometer Task", 1000, NULL, 1, &task);

    if( status != pdPASS )
    {
        PRINTF_INFO("Could not create Accelerometer Task \r\n");
    }

    // Create ADC task
    status = xTaskCreate(adc_task, "ADC Task", 1000, NULL, 1, &task);

    if( status != pdPASS )
    {
        PRINTF_INFO("Could not create ADC Task \r\n");
    }

    // Create LCD task
    status = xTaskCreate(lcd_task, "LCD Task", 1000, NULL, 1, &task);

    if( status != pdPASS )
    {
        PRINTF_INFO("Could not create LCD Task \r\n");
    }

    // Create Touch task
    status = xTaskCreate(touch_task, "Touch Task", 1000, NULL, 1, &task);

    if( status != pdPASS )
    {
        PRINTF_INFO("Could not create Touch Task \r\n");
    }

    // Use main_thread_entry to blink the board leds
    while (1)
    {
        //Turn on LED1 for 50ms)
        bsp_led_on(BSP_LED1);
        bsp_led_on(BSP_LED2);
        bsp_led_on(BSP_LED3);
        vTaskDelay(50);

        //Turn on LED2 for 950ms)
        bsp_led_off(BSP_LED1);
        bsp_led_off(BSP_LED2);
        bsp_led_off(BSP_LED3);
        vTaskDelay(950);
    }
}



