#include "m13_ra6m3_ek_lcd.h"
#include "m13_ra6m3_ek_vcom.h"

#define TOLERANCE   200
#define THRESHOLD   1700

#define BL_ON       1
#define BL_OFF      0

extern uint16_t screen_rotation;
extern int16_t ax;
extern int16_t ay;
extern int16_t az;
int8_t ay_toggle = 0;

void lcd_rotation_check(uint16_t *x_rot, uint16_t *y_rot);
void lcd_display_test_screen(void);

/* LCD Thread entry function */

void lcd_task(void *parameters)
{

    uint8_t vsync;

    uint16_t x_touch_rot = 0;
    uint16_t y_touch_rot = 0;

    FSP_PARAMETER_NOT_USED (parameters);

    // Configure lcd pins
    bsp_lcd_io_init();

    // turn on backlight
    bsp_lcd_set_backlight(BL_ON);

    // Initialize lcd controller
    bsp_lcd_init();

    // Start lcd display
    bsp_lcd_display_on();

    // Enable double buffer
    bsp_lcd_enable_double_buffer();

    // clear lcd buffer
    bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);


    // Set background color
    bsp_lcd_set_background_color(LCD_DEFAULT_BACKGROUND_COLOR);

    // Set text color to default color
    bsp_lcd_set_text_color(LCD_DEFAULT_TEXT_COLOR);

    // Set font color
    bsp_lcd_set_font(&font_14x19);

    // Set screen rotation to default
    screen_rotation = ROTATION_ZERO;

    display_runtime_cfg_t * disp_rt_cfg;

    while(1)
    {
        lcd_rotation_check(&x_touch_rot, &y_touch_rot);

#if ENABLE_GRAPHIC_LAYER2

        if (screen_rotation == ROTATION_ZERO)
        {
            bsp_layer_fade(1);
        }
        else
        {
            bsp_layer_fade(2);
        }

#else
        lcd_display_test_screen();

        if (BSP_LCD_MAX_FRAME_BUFFER > 1)
        {
            bsp_lcd_swap_buffer();
        }

        vsync_wait();
#endif
    }
}

void lcd_rotation_check(uint16_t *x_rot, uint16_t *y_rot)
{
    if( (ay > (THRESHOLD + TOLERANCE) ) && (ay_toggle == 0) )
    {
        screen_rotation = ROTATION_180;

        if (BSP_LCD_MAX_FRAME_BUFFER <= 1)
        {
            bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);
        }

#if ENABLE_GRAPHIC_LAYER2
        bsp_lcd_set_working_buffer(2);
        bsp_lcd_clear(LCD_COLOR_RED);
#endif
        ay_toggle = 1;

        *x_rot = LCD_WIDTH;
        *y_rot = LCD_HEIGHT;

        PRINTF_INFO(" Screen ROTATION_180 \r\n");
    }
    else if( (ay <= (THRESHOLD) ) && (ay_toggle == 1) )
    {
        screen_rotation = ROTATION_ZERO;

        if (BSP_LCD_MAX_FRAME_BUFFER <= 1)
        {
            bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);
        }

#if ENABLE_GRAPHIC_LAYER2
        bsp_lcd_set_working_buffer(1);
        bsp_lcd_clear(LCD_COLOR_BLUE);
#endif
        ay_toggle = 0;

        *x_rot = 0;
        *y_rot = 0;

        PRINTF_INFO(" Screen ROTATION_ZERO \r\n");
    }
    else
    {

    }
}
void lcd_display_test_screen(void)
{
#if 1

    if (BSP_LCD_MAX_FRAME_BUFFER > 1)
    {
        bsp_lcd_clear(LCD_DEFAULT_BACKGROUND_COLOR);
    }

    bsp_lcd_set_text_color(LCD_DEFAULT_TEXT_COLOR);

    bsp_lcd_set_font(&font_14x19);
    bsp_lcd_display_string(177, 30, "M13DESIGN");

    bsp_lcd_set_font(&font_14x19);
    bsp_lcd_display_string(156, 60, "M13-RA6M3-EK");

    bsp_lcd_set_text_color(LCD_COLOR_BLUE);
    bsp_lcd_set_font(&font_12x18);
    bsp_lcd_display_string(132, 150, "http server demo !");
#else
    bsp_lcd_clear(LCD_COLOR_GREEN);
#endif
}


