#include "m13_ra6m3_ek_touch.h"
#include "m13_ra6m3_ek_lcd.h"
#include "m13_ra6m3_ek_vcom.h"
#include "common_data.h"
#include <stdlib.h>

/* Touch Thread entry function */

extern uint16_t screen_rotation;
extern SemaphoreHandle_t g_touch_semaphore;

extern SemaphoreHandle_t i2c_channel_0_semaphore;

/* pvParameters contains TaskHandle_t */
void touch_task(void *pvParameters)
{
    FSP_PARAMETER_NOT_USED (pvParameters);

    uint8_t touch_status = 0;
    uint8_t touch_data[31];

    uint16_t x_pos[5];
    uint16_t y_pos[5];
    bsp_status_t error;

    while (1)
    {
        /* Wait for IRQ from touch controller. */
        xSemaphoreTake(g_touch_semaphore, portMAX_DELAY);

        xSemaphoreTake(i2c_channel_0_semaphore, portMAX_DELAY);

        error = bsp_touch_get_status(&touch_status);

        xSemaphoreGive(i2c_channel_0_semaphore);


        if(touch_status >= 1 && touch_status <= 5)
        {
            xSemaphoreTake(i2c_channel_0_semaphore, portMAX_DELAY);

            error = bsp_touch_get_data(touch_data, sizeof(touch_data));

            xSemaphoreGive(i2c_channel_0_semaphore);

             // Retrieve and form finger position data
         for(uint8_t i = 0; i < touch_status; i++)
         {
             bsp_touch_get_position(touch_data, ID_FINGER(i), &x_pos[i], &y_pos[i]);
         }

         PRINTF_INFO("\r\n Number of finger detected  = %0d \r\n", ID_FINGER(touch_status - 1));

         PRINTF_INFO("       T1|   T2|   T3|   T4|   T5| \r\n");
         PRINTF_INFO(" X =");

         for(uint8_t i = 0; i < touch_status; i++)
         {
             if(screen_rotation == ROTATION_ZERO)
             {
                 PRINTF_INFO("  %3d|", x_pos[i]);
             }
             else if(screen_rotation == ROTATION_180)
             {
                 PRINTF_INFO("  %3d|", abs(x_pos[i] - LCD_WIDTH) );
             }
         }

         PRINTF_INFO("\r\n");
         PRINTF_INFO(" Y =");

         for(uint8_t i = 0; i < touch_status; i++)
         {
             if(screen_rotation == ROTATION_ZERO)
             {
                 PRINTF_INFO("  %3d|", y_pos[i]);
             }
             else if(screen_rotation == ROTATION_180)
             {
                 PRINTF_INFO("  %3d|", abs(y_pos[i] - LCD_HEIGHT) );
             }
         }

         PRINTF_INFO("\r\n");
     }

    // Reset touch status value
    touch_status = 0;

    vTaskDelay (500);

    }
}
